﻿using System.ComponentModel;
using Hotline.Share.Dtos;
using Hotline.Share.Enums.Settings;
using Hotline.Users;
using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.Orders
{
    [Description("重办")]
    public class OrderRedo : CreationEntity
    {
        /// <summary>
        /// 工单编号（冗余）
        /// </summary>
        public string No { get; set; }

        /// <summary>
        /// 工单ID
        /// </summary>
        public string OrderId { get; set; }

        /// <summary>
        /// 工单
        /// </summary>
        [Navigate(NavigateType.OneToOne, nameof(OrderId))]
        public Order Order { get; set; }


        /// <summary>
        /// 重办时限
        /// </summary>
        public int RedoNum { get; set; }

        /// <summary>
        /// 重办时间单位
        /// </summary>
        public ETimeType RedoUnit { get; set; }

        /// <summary>
        /// 重办理由
        /// </summary>
        public IdName OrderRedoReason { get; set; }

        /// <summary>
        /// 重办意见
        /// </summary>
        public string RedoOpinion { get; set; }

        /// <summary>
        /// 附件
        /// </summary>
        [SugarColumn(ColumnDataType = "json", IsJson = true, IsNullable = true)]
        public List<string> FileIds { get; set; }


        #region 一级部门
        /// <summary>
        /// 一级部门Code
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string OrgLevelOneCode { get; set; }

        /// <summary>
        /// 一级部门名称
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string OrgLevelOneName { get; set; }

        #endregion

        #region 实际办理部门

        /// <summary>
        /// 实际办理部门编码
        /// </summary>
        public string ActualHandleOrgCode { get; set; }

        /// <summary>
        /// 实际办理部门名称
        /// </summary>
        public string ActualHandleOrgName { get; set; }

        #endregion

        #region 要求重办部门和人

        /// <summary>
        /// 要求重办人
        /// </summary>
        public string EmployeeId { get; set; }

        /// <summary>
        /// 要求重办人
        /// </summary>
        [Navigate(NavigateType.OneToOne, nameof(EmployeeId))]
        public User Employee { get; set; }

        /// <summary>
        /// 要求重办部门编码
        /// </summary>
        public string RedoOrgCode { get; set; }

        /// <summary>
        /// 要求重办部门名称
        /// </summary>
        public string RedoOrgName { get; set; }

        #endregion
    }
}
